You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@libcloud.apache.org by to...@apache.org on 2013/11/03 10:15:25 UTC

[7/9] git commit: Update GCE driver to API version v1beta16 Most of the changes are in the test fixtures, some were regenerated, some were just had URLs updated as necessary. In addition, there were some changes made to the tests to use the regenerated t

Update GCE driver to API version v1beta16 Most of the changes are in the test fixtures, some were regenerated, some were just had URLs updated as necessary. In addition, there were some changes made to the tests to use the regenerated test fixtures.

Signed-off-by: Tomaz Muraus <to...@apache.org>


Project: http://git-wip-us.apache.org/repos/asf/libcloud/repo
Commit: http://git-wip-us.apache.org/repos/asf/libcloud/commit/ac04f363
Tree: http://git-wip-us.apache.org/repos/asf/libcloud/tree/ac04f363
Diff: http://git-wip-us.apache.org/repos/asf/libcloud/diff/ac04f363

Branch: refs/heads/trunk
Commit: ac04f3631affa4c54c1df79ffe804c18619ede71
Parents: 4c23c97
Author: Rick Wright <ri...@google.com>
Authored: Fri Nov 1 16:42:34 2013 -0700
Committer: Tomaz Muraus <to...@apache.org>
Committed: Sun Nov 3 08:21:07 2013 +0000

----------------------------------------------------------------------
 demos/gce_demo.py                               |    4 +-
 demos/gce_lb_demo.py                            |    4 +-
 libcloud/common/google.py                       |    2 +-
 libcloud/compute/drivers/gce.py                 |   31 +-
 .../fixtures/gce/aggregated_addresses.json      |   18 +-
 .../compute/fixtures/gce/aggregated_disks.json  |   91 +-
 .../gce/aggregated_forwardingRules.json         |   10 +-
 .../fixtures/gce/aggregated_instances.json      |  260 +--
 .../fixtures/gce/aggregated_machineTypes.json   | 1536 +++++++++---------
 .../fixtures/gce/aggregated_targetPools.json    |   47 +-
 .../compute/fixtures/gce/global_firewalls.json  |   55 +-
 .../gce/global_firewalls_lcfirewall.json        |    4 +-
 .../gce/global_firewalls_lcfirewall_delete.json |    4 +-
 .../gce/global_firewalls_lcfirewall_put.json    |    4 +-
 .../fixtures/gce/global_firewalls_post.json     |    4 +-
 .../fixtures/gce/global_httpHealthChecks.json   |    6 +-
 .../global_httpHealthChecks_basic-check.json    |    2 +-
 .../global_httpHealthChecks_lchealthcheck.json  |    2 +-
 ...l_httpHealthChecks_lchealthcheck_delete.json |    4 +-
 ...obal_httpHealthChecks_lchealthcheck_put.json |    4 +-
 ...althChecks_libcloud-lb-demo-healthcheck.json |    2 +-
 .../gce/global_httpHealthChecks_post.json       |    4 +-
 .../compute/fixtures/gce/global_images.json     |    6 +-
 .../fixtures/gce/global_images.json.save        |   22 -
 .../compute/fixtures/gce/global_networks.json   |    8 +-
 .../fixtures/gce/global_networks_default.json   |    2 +-
 .../fixtures/gce/global_networks_lcnetwork.json |    2 +-
 .../gce/global_networks_lcnetwork_delete.json   |    4 +-
 ...l_networks_libcloud-demo-europe-network.json |    2 +-
 .../global_networks_libcloud-demo-network.json  |    2 +-
 .../fixtures/gce/global_networks_post.json      |    4 +-
 ...tion_global_firewalls_lcfirewall_delete.json |    4 +-
 ...eration_global_firewalls_lcfirewall_put.json |    4 +-
 ...rations_operation_global_firewalls_post.json |    4 +-
 ...l_httpHealthChecks_lchealthcheck_delete.json |    4 +-
 ...obal_httpHealthChecks_lchealthcheck_put.json |    4 +-
 ..._operation_global_httpHealthChecks_post.json |    4 +-
 ...ration_global_networks_lcnetwork_delete.json |    4 +-
 ...erations_operation_global_networks_post.json |    4 +-
 ..._us-central1_addresses_lcaddress_delete.json |    6 +-
 ...tion_regions_us-central1_addresses_post.json |    6 +-
 ...forwardingRules_lcforwardingrule_delete.json |    6 +-
 ...egions_us-central1_forwardingRules_post.json |    6 +-
 ...tPools_lctargetpool_addHealthCheck_post.json |    6 +-
 ...rgetPools_lctargetpool_addInstance_post.json |    6 +-
 ...entral1_targetPools_lctargetpool_delete.json |    6 +-
 ...ols_lctargetpool_removeHealthCheck_post.json |    6 +-
 ...tPools_lctargetpool_removeInstance_post.json |    6 +-
 ...on_regions_us-central1_targetPools_post.json |    6 +-
 ...ion_zones_europe-west1-a_instances_post.json |    6 +-
 ...zones_us-central1-a_disks_lcdisk_delete.json |    6 +-
 ...peration_zones_us-central1-a_disks_post.json |    6 +-
 ...-central1-a_instances_lcnode-000_delete.json |    6 +-
 ...-central1-a_instances_lcnode-001_delete.json |    6 +-
 ...1-a_instances_node-name_attachDisk_post.json |    6 +-
 ...s-central1-a_instances_node-name_delete.json |    6 +-
 ...1-a_instances_node-name_detachDisk_post.json |    6 +-
 ...ntral1-a_instances_node-name_reset_post.json |    6 +-
 ...ral1-a_instances_node-name_setTags_post.json |    6 +-
 ...tion_zones_us-central1-a_instances_post.json |    6 +-
 libcloud/test/compute/fixtures/gce/project.json |   49 +-
 .../projects_debian-cloud_global_images.json    |  164 +-
 libcloud/test/compute/fixtures/gce/regions.json |   84 +-
 .../gce/regions_us-central1_addresses.json      |   10 +-
 ...regions_us-central1_addresses_lcaddress.json |    4 +-
 ..._us-central1_addresses_lcaddress_delete.json |    6 +-
 .../gce/regions_us-central1_addresses_post.json |    6 +-
 .../regions_us-central1_forwardingRules.json    |   14 +-
 ...ntral1_forwardingRules_lcforwardingrule.json |    6 +-
 ...forwardingRules_lcforwardingrule_delete.json |    6 +-
 ...al1_forwardingRules_libcloud-lb-demo-lb.json |    6 +-
 ...egions_us-central1_forwardingRules_post.json |    6 +-
 .../gce/regions_us-central1_targetPools.json    |   24 +-
 ...ns_us-central1_targetPools_lctargetpool.json |   10 +-
 ...tPools_lctargetpool_addHealthCheck_post.json |    6 +-
 ...rgetPools_lctargetpool_addInstance_post.json |    6 +-
 ...entral1_targetPools_lctargetpool_delete.json |    6 +-
 ...ols_lctargetpool_removeHealthCheck_post.json |    6 +-
 ...tPools_lctargetpool_removeInstance_post.json |    6 +-
 ...ral1_targetPools_libcloud-lb-demo-lb-tp.json |   12 +-
 .../regions_us-central1_targetPools_post.json   |    6 +-
 ...egions_us-central1_targetPools_www-pool.json |   12 +-
 libcloud/test/compute/fixtures/gce/zones.json   |  169 +-
 .../gce/zones_europe-west1-a_instances.json     |   73 +-
 .../zones_europe-west1-a_instances_post.json    |    6 +-
 ...rope-west1-a_machineTypes_n1-standard-1.json |    2 +-
 .../fixtures/gce/zones_us-central1-a.json       |   34 +-
 .../fixtures/gce/zones_us-central1-a_disks.json |   14 +-
 .../gce/zones_us-central1-a_disks_lcdisk.json   |    4 +-
 ...zones_us-central1-a_disks_lcdisk_delete.json |    6 +-
 .../gce/zones_us-central1-a_disks_post.json     |    6 +-
 .../gce/zones_us-central1-a_instances.json      |   54 +-
 ...ones_us-central1-a_instances_lcnode-000.json |   10 +-
 ...-central1-a_instances_lcnode-000_delete.json |    6 +-
 ...ones_us-central1-a_instances_lcnode-001.json |   10 +-
 ...-central1-a_instances_lcnode-001_delete.json |    6 +-
 ...zones_us-central1-a_instances_node-name.json |   10 +-
 ...1-a_instances_node-name_attachDisk_post.json |    6 +-
 ...s-central1-a_instances_node-name_delete.json |    6 +-
 ...1-a_instances_node-name_detachDisk_post.json |    6 +-
 ...ntral1-a_instances_node-name_reset_post.json |    6 +-
 ...ral1-a_instances_node-name_setTags_post.json |    6 +-
 .../gce/zones_us-central1-a_instances_post.json |    6 +-
 .../gce/zones_us-central1-a_machineTypes.json   |   46 +-
 ...s-central1-a_machineTypes_n1-standard-1.json |    2 +-
 ...l1-b_instances_libcloud-lb-demo-www-000.json |   12 +-
 ...l1-b_instances_libcloud-lb-demo-www-001.json |   12 +-
 libcloud/test/compute/test_gce.py               |   32 +-
 libcloud/test/loadbalancer/test_gce.py          |    2 +-
 109 files changed, 1709 insertions(+), 1606 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/libcloud/blob/ac04f363/demos/gce_demo.py
----------------------------------------------------------------------
diff --git a/demos/gce_demo.py b/demos/gce_demo.py
index ef44254..b6f2cb4 100755
--- a/demos/gce_demo.py
+++ b/demos/gce_demo.py
@@ -64,7 +64,7 @@ MAX_NODES = 5
 DEMO_BASE_NAME = 'libcloud-demo'
 
 # Datacenter to create resources in
-DATACENTER = 'us-central2-a'
+DATACENTER = 'us-central1-a'
 
 # Clean up resources at the end (can be set to false in order to
 # inspect resources at the end of the run). Resources will be cleaned
@@ -284,7 +284,7 @@ def main():
 
     if CLEANUP:
         print('Cleaning up %s resources created.' % DEMO_BASE_NAME)
-        clean_up(DEMO_BASE_NAME, nodes,
+        clean_up(gce, DEMO_BASE_NAME, nodes,
                  addresses + volumes + firewalls + networks)
 
 if __name__ == '__main__':

http://git-wip-us.apache.org/repos/asf/libcloud/blob/ac04f363/demos/gce_lb_demo.py
----------------------------------------------------------------------
diff --git a/demos/gce_lb_demo.py b/demos/gce_lb_demo.py
index 0862a69..76bfeda 100755
--- a/demos/gce_lb_demo.py
+++ b/demos/gce_lb_demo.py
@@ -72,7 +72,7 @@ from libcloud.loadbalancer.providers import get_driver as get_driver_lb
 DEMO_BASE_NAME = 'libcloud-lb-demo'
 
 # Datacenter to create resources in
-DATACENTER = 'us-central1-b'
+DATACENTER = 'us-central1-a'
 
 # Clean up resources at the end (can be set to false in order to
 # inspect resources at the end of the run). Resources will be cleaned
@@ -296,7 +296,7 @@ def main():
         firewalls = gce.ex_list_firewalls()
 
         print('Cleaning up %s resources created.' % DEMO_BASE_NAME)
-        clean_up(DEMO_BASE_NAME, nodes, balancers + healthchecks + firewalls)
+        clean_up(gce, DEMO_BASE_NAME, nodes, balancers + healthchecks + firewalls)
 
 if __name__ == '__main__':
     main()

http://git-wip-us.apache.org/repos/asf/libcloud/blob/ac04f363/libcloud/common/google.py
----------------------------------------------------------------------
diff --git a/libcloud/common/google.py b/libcloud/common/google.py
index 575bc6b..549ba8b 100644
--- a/libcloud/common/google.py
+++ b/libcloud/common/google.py
@@ -447,7 +447,7 @@ class GoogleBaseConnection(ConnectionUserAndKey, PollingConnection):
     responseCls = GoogleResponse
     host = 'www.googleapis.com'
     poll_interval = 2.0
-    timeout = 120
+    timeout = 180
 
     def __init__(self, user_id, key, auth_type=None,
                  credential_file=None, **kwargs):

http://git-wip-us.apache.org/repos/asf/libcloud/blob/ac04f363/libcloud/compute/drivers/gce.py
----------------------------------------------------------------------
diff --git a/libcloud/test/compute/fixtures/gce/aggregated_addresses.json b/libcloud/test/compute/fixtures/gce/aggregated_addresses.json
index 6ac222e..eee3552 100644
--- a/libcloud/test/compute/fixtures/gce/aggregated_addresses.json
+++ b/libcloud/test/compute/fixtures/gce/aggregated_addresses.json
@@ -10,8 +10,8 @@
           "id": "10955781597205896134",
           "kind": "compute#address",
           "name": "libcloud-demo-europe-address",
-          "region": "https://www.googleapis.com/compute/v1beta15/projects/project_name/regions/europe-west1",
-          "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/regions/europe-west1/addresses/libcloud-demo-europe-address",
+          "region": "https://www.googleapis.com/compute/v1beta16/projects/project_name/regions/europe-west1",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/regions/europe-west1/addresses/libcloud-demo-europe-address",
           "status": "RESERVED"
         }
       ]
@@ -25,8 +25,8 @@
           "id": "01531551729918243104",
           "kind": "compute#address",
           "name": "lcaddress",
-          "region": "https://www.googleapis.com/compute/v1beta15/projects/project_name/regions/us-central1",
-          "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/regions/us-central1/addresses/lcaddress",
+          "region": "https://www.googleapis.com/compute/v1beta16/projects/project_name/regions/us-central1",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/regions/us-central1/addresses/lcaddress",
           "status": "RESERVED"
         },
         {
@@ -36,8 +36,8 @@
           "id": "17634862894218443422",
           "kind": "compute#address",
           "name": "libcloud-demo-address",
-          "region": "https://www.googleapis.com/compute/v1beta15/projects/project_name/regions/us-central1",
-          "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/regions/us-central1/addresses/libcloud-demo-address",
+          "region": "https://www.googleapis.com/compute/v1beta16/projects/project_name/regions/us-central1",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/regions/us-central1/addresses/libcloud-demo-address",
           "status": "RESERVED"
         },
         {
@@ -47,8 +47,8 @@
           "id": "11879548153827627972",
           "kind": "compute#address",
           "name": "testaddress",
-          "region": "https://www.googleapis.com/compute/v1beta15/projects/project_name/regions/us-central1",
-          "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/regions/us-central1/addresses/testaddress",
+          "region": "https://www.googleapis.com/compute/v1beta16/projects/project_name/regions/us-central1",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/regions/us-central1/addresses/testaddress",
           "status": "RESERVED"
         }
       ]
@@ -67,5 +67,5 @@
     }
   },
   "kind": "compute#addressAggregatedList",
-  "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/aggregated/addresses"
+  "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/aggregated/addresses"
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/libcloud/blob/ac04f363/libcloud/test/compute/fixtures/gce/aggregated_disks.json
----------------------------------------------------------------------
diff --git a/libcloud/test/compute/fixtures/gce/aggregated_disks.json b/libcloud/test/compute/fixtures/gce/aggregated_disks.json
index 1190ab4..00d9112 100644
--- a/libcloud/test/compute/fixtures/gce/aggregated_disks.json
+++ b/libcloud/test/compute/fixtures/gce/aggregated_disks.json
@@ -4,14 +4,25 @@
     "zones/europe-west1-a": {
       "disks": [
         {
-          "creationTimestamp": "2013-06-26T09:50:22.508-07:00",
-          "id": "0811494794539478718",
+          "creationTimestamp": "2013-11-01T14:45:38.422-07:00",
+          "description": "Image: https://www.googleapis.com/compute/v1beta16/projects/debian-cloud/global/images/debian-7-wheezy-v20131014",
+          "id": "4294778976520895166",
           "kind": "compute#disk",
           "name": "libcloud-demo-europe-boot-disk",
-          "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/europe-west1-a/disks/libcloud-demo-europe-boot-disk",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/europe-west1-a/disks/libcloud-demo-europe-boot-disk",
           "sizeGb": "10",
           "status": "READY",
-          "zone": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/europe-west1-a"
+          "zone": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/europe-west1-a"
+        },
+        {
+          "creationTimestamp": "2013-11-01T14:45:27.063-07:00",
+          "id": "2488119868186709482",
+          "kind": "compute#disk",
+          "name": "libcloud-demo-europe-attach-disk",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/europe-west1-a/disks/libcloud-demo-europe-attach-disk",
+          "sizeGb": "1",
+          "status": "READY",
+          "zone": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/europe-west1-a"
         }
       ]
     },
@@ -28,54 +39,58 @@
       }
     },
     "zones/us-central1-a": {
+      "warning": {
+        "code": "NO_RESULTS_ON_PAGE",
+        "data": [
+          {
+            "key": "scope",
+            "value": "zones/us-central1-a"
+          }
+        ],
+        "message": "There are no results for scope 'zones/us-central1-a' on this page."
+      }
+    },
+    "zones/us-central1-b": {
       "disks": [
         {
-          "creationTimestamp": "2013-06-25T10:57:34.305-07:00",
-          "id": "14383387450728762434",
+          "creationTimestamp": "2013-09-04T11:03:54.122-07:00",
+          "description": "Persistent boot disk created from https://www.googleapis.com/compute/v1beta15/projects/debian-cloud/global/images/debian-7-wheezy-v20130723.",
+          "id": "8658241308250794904",
           "kind": "compute#disk",
-          "name": "test-disk",
-          "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a/disks/test-disk",
+          "name": "test1",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central1-b/disks/test1",
           "sizeGb": "10",
           "status": "READY",
-          "zone": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a"
+          "zone": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central1-b"
+        }
+      ]
+    },
+    "zones/us-central2-a": {
+      "disks": [
+        {
+          "creationTimestamp": "2013-11-01T14:43:36.763-07:00",
+          "id": "01690270691106097961",
+          "kind": "compute#disk",
+          "name": "libcloud-demo-attach-disk",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a/disks/libcloud-demo-attach-disk",
+          "sizeGb": "1",
+          "status": "READY",
+          "zone": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a"
         },
         {
-          "creationTimestamp": "2013-06-26T09:47:09.178-07:00",
-          "id": "10880026303683859871",
+          "creationTimestamp": "2013-11-01T14:43:46.039-07:00",
+          "description": "Image: https://www.googleapis.com/compute/v1beta16/projects/debian-cloud/global/images/debian-7-wheezy-v20131014",
+          "id": "01805374214887472027",
           "kind": "compute#disk",
           "name": "libcloud-demo-boot-disk",
-          "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a/disks/libcloud-demo-boot-disk",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a/disks/libcloud-demo-boot-disk",
           "sizeGb": "10",
           "status": "READY",
-          "zone": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a"
+          "zone": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a"
         }
       ]
-    },
-    "zones/us-central1-b": {
-      "warning": {
-        "code": "NO_RESULTS_ON_PAGE",
-        "data": [
-          {
-            "key": "scope",
-            "value": "zones/us-central1-b"
-          }
-        ],
-        "message": "There are no results for scope 'zones/us-central1-b' on this page."
-      }
-    },
-    "zones/us-central2-a": {
-      "warning": {
-        "code": "NO_RESULTS_ON_PAGE",
-        "data": [
-          {
-            "key": "scope",
-            "value": "zones/us-central2-a"
-          }
-        ],
-        "message": "There are no results for scope 'zones/us-central2-a' on this page."
-      }
     }
   },
   "kind": "compute#diskAggregatedList",
-  "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/aggregated/disks"
+  "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/aggregated/disks"
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/libcloud/blob/ac04f363/libcloud/test/compute/fixtures/gce/aggregated_forwardingRules.json
----------------------------------------------------------------------
diff --git a/libcloud/test/compute/fixtures/gce/aggregated_forwardingRules.json b/libcloud/test/compute/fixtures/gce/aggregated_forwardingRules.json
index c6f648a..fd3827b 100644
--- a/libcloud/test/compute/fixtures/gce/aggregated_forwardingRules.json
+++ b/libcloud/test/compute/fixtures/gce/aggregated_forwardingRules.json
@@ -23,8 +23,8 @@
           "kind": "compute#forwardingRule",
           "name": "lcforwardingrule",
           "portRange": "8000-8500",
-          "region": "https://www.googleapis.com/compute/v1beta15/projects/project_name/regions/us-central1",
-          "target": "https://www.googleapis.com/compute/v1beta15/projects/project_name/regions/us-central1/targetPools/libcloud-lb-demo-lb-tp"
+          "region": "https://www.googleapis.com/compute/v1beta16/projects/project_name/regions/us-central1",
+          "target": "https://www.googleapis.com/compute/v1beta16/projects/project_name/regions/us-central1/targetPools/libcloud-lb-demo-lb-tp"
         },
         {
           "IPAddress": "173.255.119.185",
@@ -34,8 +34,8 @@
           "kind": "compute#forwardingRule",
           "name": "libcloud-lb-demo-lb",
           "portRange": "80-80",
-          "region": "https://www.googleapis.com/compute/v1beta15/projects/project_name/regions/us-central1",
-          "target": "https://www.googleapis.com/compute/v1beta15/projects/project_name/regions/us-central1/targetPools/libcloud-lb-demo-lb-tp"
+          "region": "https://www.googleapis.com/compute/v1beta16/projects/project_name/regions/us-central1",
+          "target": "https://www.googleapis.com/compute/v1beta16/projects/project_name/regions/us-central1/targetPools/libcloud-lb-demo-lb-tp"
         }
       ]
     },
@@ -53,5 +53,5 @@
     }
   },
   "kind": "compute#forwardingRuleAggregatedList",
-  "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/aggregated/forwardingRules"
+  "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/aggregated/forwardingRules"
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/libcloud/blob/ac04f363/libcloud/test/compute/fixtures/gce/aggregated_instances.json
----------------------------------------------------------------------
diff --git a/libcloud/test/compute/fixtures/gce/aggregated_instances.json b/libcloud/test/compute/fixtures/gce/aggregated_instances.json
index 3e72aff..056cbb2 100644
--- a/libcloud/test/compute/fixtures/gce/aggregated_instances.json
+++ b/libcloud/test/compute/fixtures/gce/aggregated_instances.json
@@ -5,88 +5,90 @@
       "instances": [
         {
           "canIpForward": false,
-          "creationTimestamp": "2013-06-26T15:13:38.295-07:00",
+          "creationTimestamp": "2013-11-01T14:45:44.186-07:00",
           "disks": [
             {
+              "boot": true,
+              "deviceName": "libcloud-demo-europe-boot-disk",
               "index": 0,
               "kind": "compute#attachedDisk",
               "mode": "READ_WRITE",
-              "type": "SCRATCH"
+              "source": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/europe-west1-a/disks/libcloud-demo-europe-boot-disk",
+              "type": "PERSISTENT"
             }
           ],
-          "id": "4658881585544531189",
-          "image": "https://www.googleapis.com/compute/v1beta15/projects/debian-cloud/global/images/debian-7-wheezy-v20130617",
+          "id": "8051468456709756069",
+          "kernel": "https://www.googleapis.com/compute/v1beta16/projects/google/global/kernels/gce-no-conn-track-v20130813",
           "kind": "compute#instance",
-          "machineType": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/europe-west1-a/machineTypes/n1-standard-1",
+          "machineType": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/europe-west1-a/machineTypes/n1-standard-1",
           "metadata": {
             "fingerprint": "42WmSpB8rSM=",
             "kind": "compute#metadata"
           },
-          "name": "libcloud-demo-europe-multiple-nodes-000",
+          "name": "libcloud-demo-europe-persist-node",
           "networkInterfaces": [
             {
               "accessConfigs": [
                 {
                   "kind": "compute#accessConfig",
                   "name": "External NAT",
-                  "natIP": "192.158.29.167",
+                  "natIP": "8.34.211.23",
                   "type": "ONE_TO_ONE_NAT"
                 }
               ],
               "name": "nic0",
-              "network": "https://www.googleapis.com/compute/v1beta15/projects/project_name/global/networks/default",
-              "networkIP": "10.240.144.78"
+              "network": "https://www.googleapis.com/compute/v1beta16/projects/project_name/global/networks/default",
+              "networkIP": "10.240.188.108"
             }
           ],
-          "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/europe-west1-a/instances/libcloud-demo-europe-multiple-nodes-000",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/europe-west1-a/instances/libcloud-demo-europe-persist-node",
           "status": "RUNNING",
           "tags": {
-            "fingerprint": "W7t6ZyTyIrc=",
+            "fingerprint": "EbZdwVRtKyg=",
             "items": [
-              "libcloud"
+              "libcloud",
+              "newtag"
             ]
           },
-          "zone": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/europe-west1-a"
+          "zone": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/europe-west1-a"
         },
         {
           "canIpForward": false,
-          "creationTimestamp": "2013-06-26T15:13:21.549-07:00",
+          "creationTimestamp": "2013-11-01T14:46:02.933-07:00",
           "disks": [
             {
-              "boot": true,
-              "deviceName": "libcloud-demo-europe-boot-disk",
               "index": 0,
               "kind": "compute#attachedDisk",
               "mode": "READ_WRITE",
-              "source": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/europe-west1-a/disks/libcloud-demo-europe-boot-disk",
-              "type": "PERSISTENT"
+              "type": "SCRATCH"
             }
           ],
-          "id": "0681789716029574243",
-          "kernel": "https://www.googleapis.com/compute/v1beta15/projects/google/global/kernels/gce-v20130603",
+          "id": "04184465693678804555",
+          "image": "https://www.googleapis.com/compute/v1beta16/projects/debian-cloud/global/images/debian-7-wheezy-v20131014",
+          "kernel": "https://www.googleapis.com/compute/v1beta16/projects/google/global/kernels/gce-no-conn-track-v20130813",
           "kind": "compute#instance",
-          "machineType": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/europe-west1-a/machineTypes/n1-standard-1",
+          "machineType": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/europe-west1-a/machineTypes/n1-standard-1",
           "metadata": {
             "fingerprint": "42WmSpB8rSM=",
             "kind": "compute#metadata"
           },
-          "name": "libcloud-demo-europe-persist-node",
+          "name": "libcloud-demo-europe-multiple-nodes-000",
           "networkInterfaces": [
             {
               "accessConfigs": [
                 {
                   "kind": "compute#accessConfig",
                   "name": "External NAT",
-                  "natIP": "192.158.29.121",
+                  "natIP": "8.34.211.48",
                   "type": "ONE_TO_ONE_NAT"
                 }
               ],
               "name": "nic0",
-              "network": "https://www.googleapis.com/compute/v1beta15/projects/project_name/global/networks/default",
-              "networkIP": "10.240.206.91"
+              "network": "https://www.googleapis.com/compute/v1beta16/projects/project_name/global/networks/default",
+              "networkIP": "10.240.141.92"
             }
           ],
-          "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/europe-west1-a/instances/libcloud-demo-europe-persist-node",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/europe-west1-a/instances/libcloud-demo-europe-multiple-nodes-000",
           "status": "RUNNING",
           "tags": {
             "fingerprint": "W7t6ZyTyIrc=",
@@ -94,23 +96,32 @@
               "libcloud"
             ]
           },
-          "zone": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/europe-west1-a"
+          "zone": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/europe-west1-a"
         },
         {
           "canIpForward": false,
-          "creationTimestamp": "2013-06-26T15:12:29.726-07:00",
+          "creationTimestamp": "2013-11-01T14:44:57.127-07:00",
           "disks": [
             {
               "index": 0,
               "kind": "compute#attachedDisk",
               "mode": "READ_WRITE",
               "type": "SCRATCH"
+            },
+            {
+              "deviceName": "libcloud-demo-europe-attach-disk",
+              "index": 1,
+              "kind": "compute#attachedDisk",
+              "mode": "READ_WRITE",
+              "source": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/europe-west1-a/disks/libcloud-demo-europe-attach-disk",
+              "type": "PERSISTENT"
             }
           ],
-          "id": "14308265828754333159",
-          "image": "https://www.googleapis.com/compute/v1beta15/projects/debian-cloud/global/images/debian-7-wheezy-v20130617",
+          "id": "4450078356274958103",
+          "image": "https://www.googleapis.com/compute/v1beta16/projects/debian-cloud/global/images/debian-7-wheezy-v20131014",
+          "kernel": "https://www.googleapis.com/compute/v1beta16/projects/google/global/kernels/gce-no-conn-track-v20130813",
           "kind": "compute#instance",
-          "machineType": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/europe-west1-a/machineTypes/n1-standard-1",
+          "machineType": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/europe-west1-a/machineTypes/n1-standard-1",
           "metadata": {
             "fingerprint": "42WmSpB8rSM=",
             "kind": "compute#metadata"
@@ -122,16 +133,16 @@
                 {
                   "kind": "compute#accessConfig",
                   "name": "External NAT",
-                  "natIP": "192.158.29.88",
+                  "natIP": "8.34.208.52",
                   "type": "ONE_TO_ONE_NAT"
                 }
               ],
               "name": "nic0",
-              "network": "https://www.googleapis.com/compute/v1beta15/projects/project_name/global/networks/default",
-              "networkIP": "10.240.66.77"
+              "network": "https://www.googleapis.com/compute/v1beta16/projects/project_name/global/networks/default",
+              "networkIP": "10.240.48.164"
             }
           ],
-          "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/europe-west1-a/instances/libcloud-demo-europe-np-node",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/europe-west1-a/instances/libcloud-demo-europe-np-node",
           "status": "RUNNING",
           "tags": {
             "fingerprint": "W7t6ZyTyIrc=",
@@ -139,7 +150,7 @@
               "libcloud"
             ]
           },
-          "zone": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/europe-west1-a"
+          "zone": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/europe-west1-a"
         }
       ]
     },
@@ -159,55 +170,66 @@
       "instances": [
         {
           "canIpForward": false,
-          "creationTimestamp": "2013-06-26T15:11:02.386-07:00",
+          "creationTimestamp": "2013-11-01T14:47:29.154-07:00",
           "disks": [
             {
-              "boot": true,
-              "deviceName": "libcloud-demo-boot-disk",
               "index": 0,
               "kind": "compute#attachedDisk",
               "mode": "READ_WRITE",
-              "source": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a/disks/libcloud-demo-boot-disk",
-              "type": "PERSISTENT"
+              "type": "SCRATCH"
             }
           ],
-          "id": "2378270030714524465",
-          "kernel": "https://www.googleapis.com/compute/v1beta15/projects/google/global/kernels/gce-v20130603",
+          "id": "10348912619288589086",
+          "image": "https://www.googleapis.com/compute/v1beta16/projects/debian-cloud/global/images/debian-7-wheezy-v20130617",
+          "kernel": "https://www.googleapis.com/compute/v1beta16/projects/google/global/kernels/gce-v20130603",
           "kind": "compute#instance",
-          "machineType": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a/machineTypes/n1-standard-1",
+          "machineType": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central1-a/machineTypes/n1-standard-1",
           "metadata": {
             "fingerprint": "42WmSpB8rSM=",
             "kind": "compute#metadata"
           },
-          "name": "libcloud-demo-persist-node",
+          "name": "node-name",
           "networkInterfaces": [
             {
               "accessConfigs": [
                 {
                   "kind": "compute#accessConfig",
                   "name": "External NAT",
-                  "natIP": "108.59.81.66",
+                  "natIP": "8.35.197.91",
                   "type": "ONE_TO_ONE_NAT"
                 }
               ],
               "name": "nic0",
-              "network": "https://www.googleapis.com/compute/v1beta15/projects/project_name/global/networks/default",
-              "networkIP": "10.240.192.190"
+              "network": "https://www.googleapis.com/compute/v1beta16/projects/project_name/global/networks/default",
+              "networkIP": "10.240.123.204"
             }
           ],
-          "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a/instances/libcloud-demo-persist-node",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central1-a/instances/node-name",
           "status": "RUNNING",
           "tags": {
-            "fingerprint": "W7t6ZyTyIrc=",
-            "items": [
-              "libcloud"
-            ]
+            "fingerprint": "42WmSpB8rSM="
           },
-          "zone": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a"
-        },
+          "zone": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central1-a"
+        }
+      ]
+    },
+    "zones/us-central1-b": {
+      "warning": {
+        "code": "NO_RESULTS_ON_PAGE",
+        "data": [
+          {
+            "key": "scope",
+            "value": "zones/us-central1-b"
+          }
+        ],
+        "message": "There are no results for scope 'zones/us-central1-b' on this page."
+      }
+    },
+    "zones/us-central2-a": {
+      "instances": [
         {
           "canIpForward": false,
-          "creationTimestamp": "2013-06-26T15:11:19.247-07:00",
+          "creationTimestamp": "2013-11-01T14:44:03.801-07:00",
           "disks": [
             {
               "index": 0,
@@ -216,31 +238,32 @@
               "type": "SCRATCH"
             }
           ],
-          "id": "8573880455005118258",
-          "image": "https://www.googleapis.com/compute/v1beta15/projects/debian-cloud/global/images/debian-7-wheezy-v20130617",
+          "id": "8843444782291050664",
+          "image": "https://www.googleapis.com/compute/v1beta16/projects/debian-cloud/global/images/debian-7-wheezy-v20131014",
+          "kernel": "https://www.googleapis.com/compute/v1beta16/projects/google/global/kernels/gce-no-conn-track-v20130813",
           "kind": "compute#instance",
-          "machineType": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a/machineTypes/n1-standard-1",
+          "machineType": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a/machineTypes/n1-standard-1",
           "metadata": {
             "fingerprint": "42WmSpB8rSM=",
             "kind": "compute#metadata"
           },
-          "name": "libcloud-demo-multiple-nodes-000",
+          "name": "libcloud-demo-multiple-nodes-001",
           "networkInterfaces": [
             {
               "accessConfigs": [
                 {
                   "kind": "compute#accessConfig",
                   "name": "External NAT",
-                  "natIP": "108.59.81.107",
+                  "natIP": "173.255.121.180",
                   "type": "ONE_TO_ONE_NAT"
                 }
               ],
               "name": "nic0",
-              "network": "https://www.googleapis.com/compute/v1beta15/projects/project_name/global/networks/default",
-              "networkIP": "10.240.224.165"
+              "network": "https://www.googleapis.com/compute/v1beta16/projects/project_name/global/networks/default",
+              "networkIP": "10.240.167.120"
             }
           ],
-          "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a/instances/libcloud-demo-multiple-nodes-000",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a/instances/libcloud-demo-multiple-nodes-001",
           "status": "RUNNING",
           "tags": {
             "fingerprint": "W7t6ZyTyIrc=",
@@ -248,53 +271,60 @@
               "libcloud"
             ]
           },
-          "zone": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a"
+          "zone": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a"
         },
         {
           "canIpForward": false,
-          "creationTimestamp": "2013-06-26T15:00:12.021-07:00",
+          "creationTimestamp": "2013-11-01T14:43:49.457-07:00",
           "disks": [
             {
+              "boot": true,
+              "deviceName": "libcloud-demo-boot-disk",
               "index": 0,
               "kind": "compute#attachedDisk",
               "mode": "READ_WRITE",
-              "type": "SCRATCH"
+              "source": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a/disks/libcloud-demo-boot-disk",
+              "type": "PERSISTENT"
             }
           ],
-          "id": "1845312225624811608",
-          "image": "https://www.googleapis.com/compute/v1beta15/projects/debian-cloud/global/images/debian-7-wheezy-v20130617",
+          "id": "2278280472037226745",
+          "kernel": "https://www.googleapis.com/compute/v1beta16/projects/google/global/kernels/gce-no-conn-track-v20130813",
           "kind": "compute#instance",
-          "machineType": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a/machineTypes/n1-standard-1",
+          "machineType": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a/machineTypes/n1-standard-1",
           "metadata": {
             "fingerprint": "42WmSpB8rSM=",
             "kind": "compute#metadata"
           },
-          "name": "node-name",
+          "name": "libcloud-demo-persist-node",
           "networkInterfaces": [
             {
               "accessConfigs": [
                 {
                   "kind": "compute#accessConfig",
                   "name": "External NAT",
-                  "natIP": "173.255.115.146",
+                  "natIP": "173.255.121.109",
                   "type": "ONE_TO_ONE_NAT"
                 }
               ],
               "name": "nic0",
-              "network": "https://www.googleapis.com/compute/v1beta15/projects/project_name/global/networks/default",
-              "networkIP": "10.240.113.94"
+              "network": "https://www.googleapis.com/compute/v1beta16/projects/project_name/global/networks/default",
+              "networkIP": "10.240.102.153"
             }
           ],
-          "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a/instances/node-name",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a/instances/libcloud-demo-persist-node",
           "status": "RUNNING",
           "tags": {
-            "fingerprint": "42WmSpB8rSM="
+            "fingerprint": "EbZdwVRtKyg=",
+            "items": [
+              "libcloud",
+              "newtag"
+            ]
           },
-          "zone": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a"
+          "zone": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a"
         },
         {
           "canIpForward": false,
-          "creationTimestamp": "2013-06-26T15:10:09.700-07:00",
+          "creationTimestamp": "2013-11-01T14:44:03.256-07:00",
           "disks": [
             {
               "index": 0,
@@ -303,31 +333,32 @@
               "type": "SCRATCH"
             }
           ],
-          "id": "03138438763739542377",
-          "image": "https://www.googleapis.com/compute/v1beta15/projects/debian-cloud/global/images/debian-7-wheezy-v20130617",
+          "id": "0994482023759804723",
+          "image": "https://www.googleapis.com/compute/v1beta16/projects/debian-cloud/global/images/debian-7-wheezy-v20131014",
+          "kernel": "https://www.googleapis.com/compute/v1beta16/projects/google/global/kernels/gce-no-conn-track-v20130813",
           "kind": "compute#instance",
-          "machineType": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a/machineTypes/n1-standard-1",
+          "machineType": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a/machineTypes/n1-standard-1",
           "metadata": {
             "fingerprint": "42WmSpB8rSM=",
             "kind": "compute#metadata"
           },
-          "name": "libcloud-demo-np-node",
+          "name": "libcloud-demo-multiple-nodes-000",
           "networkInterfaces": [
             {
               "accessConfigs": [
                 {
                   "kind": "compute#accessConfig",
                   "name": "External NAT",
-                  "natIP": "108.59.80.244",
+                  "natIP": "173.255.121.133",
                   "type": "ONE_TO_ONE_NAT"
                 }
               ],
               "name": "nic0",
-              "network": "https://www.googleapis.com/compute/v1beta15/projects/project_name/global/networks/default",
-              "networkIP": "10.240.147.18"
+              "network": "https://www.googleapis.com/compute/v1beta16/projects/project_name/global/networks/default",
+              "networkIP": "10.240.164.41"
             }
           ],
-          "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a/instances/libcloud-demo-np-node",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a/instances/libcloud-demo-multiple-nodes-000",
           "status": "RUNNING",
           "tags": {
             "fingerprint": "W7t6ZyTyIrc=",
@@ -335,44 +366,53 @@
               "libcloud"
             ]
           },
-          "zone": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a"
+          "zone": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a"
         },
         {
           "canIpForward": false,
-          "creationTimestamp": "2013-06-26T15:11:19.662-07:00",
+          "creationTimestamp": "2013-11-01T14:43:15.485-07:00",
           "disks": [
             {
               "index": 0,
               "kind": "compute#attachedDisk",
               "mode": "READ_WRITE",
               "type": "SCRATCH"
+            },
+            {
+              "deviceName": "libcloud-demo-attach-disk",
+              "index": 1,
+              "kind": "compute#attachedDisk",
+              "mode": "READ_WRITE",
+              "source": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a/disks/libcloud-demo-attach-disk",
+              "type": "PERSISTENT"
             }
           ],
-          "id": "17221721898919682654",
-          "image": "https://www.googleapis.com/compute/v1beta15/projects/debian-cloud/global/images/debian-7-wheezy-v20130617",
+          "id": "08480381647283539833",
+          "image": "https://www.googleapis.com/compute/v1beta16/projects/debian-cloud/global/images/debian-7-wheezy-v20131014",
+          "kernel": "https://www.googleapis.com/compute/v1beta16/projects/google/global/kernels/gce-no-conn-track-v20130813",
           "kind": "compute#instance",
-          "machineType": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a/machineTypes/n1-standard-1",
+          "machineType": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a/machineTypes/n1-standard-1",
           "metadata": {
             "fingerprint": "42WmSpB8rSM=",
             "kind": "compute#metadata"
           },
-          "name": "libcloud-demo-multiple-nodes-001",
+          "name": "libcloud-demo-np-node",
           "networkInterfaces": [
             {
               "accessConfigs": [
                 {
                   "kind": "compute#accessConfig",
                   "name": "External NAT",
-                  "natIP": "108.59.81.166",
+                  "natIP": "173.255.121.95",
                   "type": "ONE_TO_ONE_NAT"
                 }
               ],
               "name": "nic0",
-              "network": "https://www.googleapis.com/compute/v1beta15/projects/project_name/global/networks/default",
-              "networkIP": "10.240.223.109"
+              "network": "https://www.googleapis.com/compute/v1beta16/projects/project_name/global/networks/default",
+              "networkIP": "10.240.37.226"
             }
           ],
-          "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a/instances/libcloud-demo-multiple-nodes-001",
+          "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a/instances/libcloud-demo-np-node",
           "status": "RUNNING",
           "tags": {
             "fingerprint": "W7t6ZyTyIrc=",
@@ -380,35 +420,11 @@
               "libcloud"
             ]
           },
-          "zone": "https://www.googleapis.com/compute/v1beta15/projects/project_name/zones/us-central1-a"
+          "zone": "https://www.googleapis.com/compute/v1beta16/projects/project_name/zones/us-central2-a"
         }
       ]
-    },
-    "zones/us-central1-b": {
-      "warning": {
-        "code": "NO_RESULTS_ON_PAGE",
-        "data": [
-          {
-            "key": "scope",
-            "value": "zones/us-central1-b"
-          }
-        ],
-        "message": "There are no results for scope 'zones/us-central1-b' on this page."
-      }
-    },
-    "zones/us-central2-a": {
-      "warning": {
-        "code": "NO_RESULTS_ON_PAGE",
-        "data": [
-          {
-            "key": "scope",
-            "value": "zones/us-central2-a"
-          }
-        ],
-        "message": "There are no results for scope 'zones/us-central2-a' on this page."
-      }
     }
   },
   "kind": "compute#instanceAggregatedList",
-  "selfLink": "https://www.googleapis.com/compute/v1beta15/projects/project_name/aggregated/instances"
+  "selfLink": "https://www.googleapis.com/compute/v1beta16/projects/project_name/aggregated/instances"
 }
\ No newline at end of file
diff --git a/libcloud/compute/drivers/gce.py b/libcloud/compute/drivers/gce.py
index 7f3a8b3..c0ee559 100644
--- a/libcloud/compute/drivers/gce.py
+++ b/libcloud/compute/drivers/gce.py
@@ -30,7 +30,7 @@ from libcloud.compute.base import NodeSize, StorageVolume, UuidMixin
 from libcloud.compute.providers import Provider
 from libcloud.compute.types import NodeState
 
-API_VERSION = 'v1beta15'
+API_VERSION = 'v1beta16'
 DEFAULT_TASK_COMPLETION_TIMEOUT = 180
 
 
@@ -359,11 +359,10 @@ class GCETargetPool(UuidMixin):
 
 class GCEZone(NodeLocation):
     """Subclass of NodeLocation to provide additional information."""
-    def __init__(self, id, name, status, maintenance_windows, quotas,
-                 deprecated, driver, extra=None):
+    def __init__(self, id, name, status, maintenance_windows, deprecated,
+                 driver, extra=None):
         self.status = status
         self.maintenance_windows = maintenance_windows
-        self.quotas = quotas
         self.deprecated = deprecated
         self.extra = extra
         country = name.split('-')[0]
@@ -382,16 +381,19 @@ class GCEZone(NodeLocation):
         """
         Returns the next Maintenance Window.
 
         :return:  A dictionary containing maintenance window info
                   The dictionary contains 4 keys with values of type ``str``
                       - name: The name of the maintence window
                       - description: Description of the maintenance window
                       - beginTime: RFC3339 Timestamp
                       - endTime: RFC3339 Timestamp
-        :rtype:   ``dict``
+        :rtype:   ``dict`` or ``None``
         """
         begin = None
         next_window = None
+        if not self.maintenance_windows:
+            return None
         if len(self.maintenance_windows) == 1:
             return self.maintenance_windows[0]
         for mw in self.maintenance_windows:
@@ -405,10 +407,13 @@ class GCEZone(NodeLocation):
         """
         Returns time until next maintenance window.
 
-        :return:  Time until next maintenance window
-        :rtype:   :class:`datetime.timedelta`
+        :return:  Time until next maintenance window (or None if no
+                  maintenance windows are scheduled)
+        :rtype:   :class:`datetime.timedelta` or ``None``
         """
         next_window = self._get_next_maint()
+        if not next_window:
+            return None
         now = self._now()
         next_begin = timestamp_to_datetime(next_window['beginTime'])
         return next_begin - now
@@ -417,10 +422,13 @@ class GCEZone(NodeLocation):
         """
         Returns the duration of the next maintenance window.
 
-        :return:  Duration of next maintenance window
-        :rtype:   :class:`datetime.timedelta`
+        :return:  Duration of next maintenance window (or None if no
+                  maintenance windows are scheduled)
+        :rtype:   :class:`datetime.timedelta` or ``None``
         """
         next_window = self._get_next_maint()
+        if not next_window:
+            return None
         next_begin = timestamp_to_datetime(next_window['beginTime'])
         next_end = timestamp_to_datetime(next_window['endTime'])
         return next_end - next_begin
@@ -2677,5 +2685,4 @@ class GCENodeDriver(NodeDriver):
 
         return GCEZone(id=zone['id'], name=zone['name'], status=zone['status'],
                        maintenance_windows=zone.get('maintenanceWindows'),
-                       quotas=zone['quotas'], deprecated=deprecated,
-                       driver=self, extra=extra)
+                       deprecated=deprecated, driver=self, extra=extra)

http://git-wip-us.apache.org/repos/asf/libcloud/blob/ac04f363/libcloud/test/compute/fixtures/gce/aggregated_addresses.json
----------------------------------------------------------------------
@@ -382,16 +381,19 @@ class GCEZone(NodeLocation):
         Returns the next Maintenance Window.
 
-        :return:  A dictionary containing maintenance window info
+        :return:  A dictionary containing maintenance window info (or None if
+                  no maintenance windows are scheduled)
                   The dictionary contains 4 keys with values of type ``str``
                       - name: The name of the maintence window